﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2012 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

namespace HeuristicLab.Problems.Instances {
  public interface ICTAPInstance {
    /// <summary>
    /// The name of the instance
    /// </summary>
    string Name { get; }
    /// <summary>
    /// Optional! The description of the instance
    /// </summary>
    string Description { get; }

    /// <summary>
    /// An MxN Matrix with M = |Processors| and N = |Tasks|
    /// </summary>
    double[,] ExecutionCosts { get; }
    /// <summary>
    /// An NxN Matrix with N = |Tasks|
    /// </summary>
    double[,] CommunicationCosts { get; }
    /// <summary>
    /// An array of length N with N = |Tasks|
    /// </summary>
    double[] MemoryRequirements { get; }
    /// <summary>
    /// An array of length M with M = |Processors|
    /// </summary>
    double[] MemoryCapacities { get; }

    /// <summary>
    /// Optional! An array of length N with N = |Tasks|
    /// </summary>
    int[] BestKnownAssignment { get; }
    /// <summary>
    /// Optional! The quality value of the <see cref="BestKnownAssignment"/>
    /// </summary>
    double? BestKnownQuality { get; }
  }
}
